@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2004  Andreas Rver
+ * Copyright (C) 2000-2006  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -104,7 +104,7 @@
 #define SPR_FISHHEI  40
 
 /* submarine sprite size */
-#define SPR_SUBMWID 120 
+#define SPR_SUBMWID 120
 #define SPR_SUBMHEI 80
 
 /* submarine ammunition, torpedo */
@@ -136,7 +136,7 @@
 #define GAME_DEBUG_KEYS
 #endif
 
-/*   define this if you want the bonus game to be accessible 
+/*   define this if you want the bonus game to be accessible
  from the main menu. */
 #ifdef TESTER
 #define HUNT_THE_FISH
@@ -187,6 +187,12 @@ FILE *create_local_config_file(const char *name);
 FILE *open_local_data_file(const char *name);
 FILE *create_local_data_file(const char *name);
 
+/* returns the filename that would be opened with open_data_file in
+ * f, f is max len characters
+ * returns true, if the file pointer of open_data_file would be not NULL
+ */
+bool get_data_file_path(const char * fname, char * f, int len);
+
 /* Is the TT window active? */
 extern bool tt_has_focus;
 
@@ -197,7 +203,7 @@ extern bool tt_has_focus;
 int dcl_update_speed(int spd);
 
 /* for errorchecking */
-#define assert(cond,text) if (!(cond)) { printf(_("Assertion failure: %s\n"), text); exit(1); }
+#define assert_msg(cond,text) if (!(cond)) { printf(_("Assertion failure: %s\n"), text); exit(1); }
 
 //#define CONFIGDIR "/etc"
 
