@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2004  Andreas Rver
+ * Copyright (C) 2000-2006  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -85,9 +85,9 @@ void gam_arrival(void) {
     scr_writetext_center((SCREENHEI / 6), _("You are entering the"));
 
     if (strlen(lev_towername()))
-      scr_writetext_center((SCREENHEI*2 / 6), _(lev_towername()));
+      scr_writetext_broken_center((SCREENHEI*2 / 6), _(lev_towername()));
     else
-      scr_writetext_center((SCREENHEI*2 / 6), _("Nameless Tower"));
+      scr_writetext_broken_center((SCREENHEI*2 / 6), _("Nameless Tower"));
 
     if (passwd && lev_show_passwd(lev_towernr())) {
       char buf[50];
@@ -517,7 +517,7 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
   if (demo < 0) drawflags = SF_REC;
   else if (demo > 0) drawflags = SF_DEMO;
 
-  assert(!(demo && !demobuf), "Trying to play or record a null demo.");
+  assert_msg(!(demo && !demobuf), "Trying to play or record a null demo.");
 
   top_init();
 
