@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2004  Andreas Rver
+ * Copyright (C) 2000-2006  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,6 +25,10 @@
 #include <stdio.h>
 #include <fcntl.h>
 
+#ifdef __QNXNTO__
+   #include <strings.h>
+#endif // __QNXNTO__
+
 #define NUMHISCORES 10
 
 #define SCOREFNAME "toppler.hsc"
