@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2004  Andreas Rver
+ * Copyright (C) 2000-2006  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -294,7 +294,11 @@ men_options_sounds(_menusystem *ms)
     if (config.nosound()) {
       config.nosound(false);
       snd_init();
+      if (!config.nomusic())
+        snd_playTitle();
     } else {
+      if (!config.nomusic())
+        snd_stopTitle();
       snd_done();
       config.nosound(true);
     }
@@ -305,6 +309,25 @@ men_options_sounds(_menusystem *ms)
   return txt;
 }
 
+  static const char *
+men_options_music(_menusystem *ms)
+{
+  static char txt[30];
+  if (ms) {
+    if (config.nomusic()) {
+      config.nomusic(false);
+      snd_playTitle();
+    } else {
+      snd_stopTitle();
+      config.nomusic(true);
+    }
+  }
+  if (config.nomusic()) sprintf(txt, "%s %c", _("Music"), 3);
+  else sprintf(txt, "%s %c", _("Music"), 4);
+
+  return txt;
+}
+
 
 static void
 reload_font_graphics(void) {
@@ -480,6 +503,7 @@ men_options(_menusystem *mainmenu) {
     ms = add_menu_option(ms, NULL, run_redefine_menu);
     ms = add_menu_option(ms, NULL, men_options_graphic);
     ms = add_menu_option(ms, NULL, men_options_sounds);
+    ms = add_menu_option(ms, NULL, men_options_music);
 
     ms = add_menu_option(ms, NULL, NULL);
     ms = add_menu_option(ms, _("Back"), NULL);
@@ -781,7 +805,9 @@ men_main_startgame_proc(_menusystem *ms)
     switch (key_sdlkey2conv(ms->key, false)) {
     case fire_key:
       dcl_update_speed(config.game_speed());
+      snd_musicVolume(MIX_MAX_VOLUME/4);
       main_game_loop();
+      snd_musicVolume(MIX_MAX_VOLUME);
       dcl_update_speed(MENU_DCLSPEED);
       break;
     case right_key: currentmission = (currentmission + 1) % missioncount; break;
