@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2004  Andreas Rver
+ * Copyright (C) 2000-2006  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -549,10 +549,10 @@ static void loadscroller(void) {
 
   num_scrolllayers = layers;
 
-  assert(num_scrolllayers > 1, "Must have at least 2 scroll layers!");
+  assert_msg(num_scrolllayers > 1, "Must have at least 2 scroll layers!");
 
   scroll_layers = new _scroll_layer[layers];
-  assert(scroll_layers, "Failed to alloc memory for bonus scroller!");
+  assert_msg(scroll_layers, "Failed to alloc memory for bonus scroller!");
     
   towerpos = fi.getbyte();
     
@@ -640,7 +640,7 @@ void scr_init(void) {
 
 void scr_reinit() {
   display = SDL_SetVideoMode(SCREENWID, SCREENHEI, 16, (config.fullscreen()) ? (SDL_FULLSCREEN) : (0));
-  assert(display, "could not open display");
+  assert_msg(display, "could not open display");
 }
 
 void scr_done(void) {
@@ -863,6 +863,40 @@ void scr_writetext_center(long y, const char *s) {
   scr_writetext ((SCREENWID - scr_textlength(s)) / 2, y, s);
 }
 
+void scr_writetext_broken_center(long y, const char *s) {
+
+  // ok, we try to break the text into several lines, if the lines are longer then the
+  // screenwidth
+  
+  int len = strlen(s);
+  int start = 0;
+  int end = len;
+
+  while (start < len) {
+    
+    while (scr_textlength(s+start, end-start+1) > SCREENWID) {
+      end--;
+      while ((end > start) && (s[end] != ' ')) end--;
+
+      if (end == start) {
+        while ((end < len) && (s[end] != ' ')) end++;
+        break;
+      }
+    }
+    
+    if (s[end] == ' ') end--;
+    
+    scr_writetext((SCREENWID - scr_textlength(s+start, end-start+1)) / 2, y, s+start, end-start+1);
+
+    start = end+1;
+    end = len;
+    while ((start < len) && (s[start] == ' ')) start++;
+
+    y += 40;
+    
+  }
+}
+
 void scr_putbar(int x, int y, int br, int h, Uint8 colr, Uint8 colg, Uint8 colb, Uint8 alpha) {
 
   if (alpha != 255) {
@@ -1323,7 +1357,7 @@ void scr_writeformattext(long x, long y, const char *s) {
         x += 32;
         break;
       default:
-        assert(0, "Wrong command in formatted text.");
+        assert_msg(0, "Wrong command in formatted text.");
       }
       break;
     default:
@@ -1409,7 +1443,7 @@ long scr_formattextlength(long x, long y, const char *s) {
         x += 32;
         break;
       default:
-        assert(0, "Wrong command in formatted text.");
+        assert_msg(0, "Wrong command in formatted text.");
       }
       break;
     default:
