@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2004  Andreas Rver
+ * Copyright (C) 2000-2006  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -55,5 +55,9 @@ enum {
 void snd_init(void);
 void snd_done(void);
 
+void snd_playTitle(void);
+void snd_stopTitle(void);
+void snd_musicVolume(int vol);
+
 #endif
 
